//
// Functions for the welcome pages.
//
// 

var LINKTYPE_UNDEFINED = 0;
var LINKTYPE_DOWNLOAD = 1;
var LINKTYPE_MANAGEMENT = 2;
var LINKTYPE_WEBACCESS = 3;


var FIELD_LINKTYPE = 0;
var FIELD_DESCRIPTOR = 1;
var FIELD_URL = 2;
var FIELD_ID = 3;
var FIELD_TARGET = 4;
var FIELD_CUSTOM = 5;




var wpProductNames = new Array();  // Global array for product names and identifiers.
var wpI18NProductNames = new Array(); // Global array for internationalized product names.
var wpLinks = new Array(); // Global array of arrays of links for products.



function addToWpProductNames(key, value) {
    if (wpProductNames[key] === undefined) {
		wpProductNames[key] = value;
	}
}

function addToWpI18NProductNames(key, value) {
    if (wpProductNames[key] === undefined) {
        wpI18NProductNames[key] = value;
    }
}

function addToWpLinks(key, array) {
    if (wpLinks[key] !== undefined) {
        wpLinks[key] = wpLinks[key].concat(array);
    } else {
        wpLinks[key] = array;
    }
}

function getWpProductName(key) {
    return wpProductNames[key];
}

function getWpI18NProductName(key, language) {

    var langKey;
    if (language != null && language != "") {
        langKey = key + "_" + language;
    } else {
        langKey = key;
    }

    // First try for the specified language. If null is returned,
    // the language doesn't exist, so use the default.
    var productName = wpI18NProductNames[langKey];
    if (productName == null) {
        productName = wpProductNames[key];
    }

    return productName;
}

function getWpLinksOldWay(key) {

    // Get the links associated with the key.
    var myLinks = wpLinks[key];

    // myLinks contains an array of arrays. So I need to access each 
    // array individually. This will replace items like %*sererhost%
    // with the name of the host.
    if ( myLinks != null) {
        for ( var i = 0; i < myLinks.length; i ++ ) {
            replaceMacrosInArray(myLinks[i]);
        }
    }

}

function getWpLinks(key, language) {

    //document.write(" " + key + "  " + language);
    var langKey;
    if (language != null && language != "") {
        langKey = key + "_" + language;
    } else {
        langKey = key;
    }

    // Get the links associated with the key. First try for the language.
    // Then if null is returned, try the default.
    var myLinks = wpLinks[langKey];
    if (myLinks == null) {
        myLinks = wpLinks[key];
    }

    // myLinks contains an array of arrays. So I need to access each 
    // array individually. This will replace items like %*sererhost%
    // with the name of the host.
    if ( myLinks != null) {
        for ( var i = 0; i < myLinks.length; i ++ ) {
            replaceMacrosInArray(myLinks[i]);
        }
    }
    return myLinks;
}

function sortWpProductNames() {
    wpProductNames.sort();
}


/* Get a list of sorted product names. This is not an associative array. */
function getSortedWpProductKeys() {

    var sortedKeys = new Array();
    var i = 0;
    for (var key in wpProductNames) {
        sortedKeys[i] = key;
        i++;
    }
    sortedKeys.sort();
    return sortedKeys;
}



function getWpLinksByLinkType(product, language, linkType) {


    var linkArray = getWpLinks(product, language);

    if (linkArray == null) {
        // Doesn't exit.
        //document.write("<p>LinkArray was null</p>");
        return null;
    }

    var returnArray = new Array();
    for (var i = 0; i < linkArray.length; i++) {
        if ( linkArray[i][FIELD_LINKTYPE] == linkType ) {

            returnArray.push(linkArray[i]);
        }
    }

    if (returnArray.length == 0) {
        return null;
    } else {
        return returnArray;
    }

}


/**
 * Determines if any links of the specified type exist.
 * 
 * Stops checking when the first matching link is found.
 * 
 * Returns: true if they do, or false if they don't.
 */
function linksExistForType(linkType) {

    var returnValue = false;

    for (var key in wpProductNames) {

        var productName = wpProductNames[key];

        var links = getWpLinksByLinkType(key, "", linkType);
        if (links != null) {
            // Only need to know if one link exists, so 
            // stop processing after it is found.
            returnValue = true;
            break;
        }
    }

    return returnValue;
}


/**
 * Determines the language of the browser.
 * 
 * This is used to text can be displayed for the proper
 * language.
 */
function getBrowserLanguage() {

    var browserLang;
    var returnLang = "";

    // Netscape way first.
    browserLang = navigator.language;
    if (browserLang == null) {
        //Else try the ie way.
        browserLang = navigator.userLanguage;

        // If it's still undefined. I don't know what to do.
        if (browserLang == null) {
            browserLang = "";
        }
    }

    if (browserLang == "" ) {
        returnLang = "";
    } else if (browserLang.indexOf("en") == 0) {
        returnLang = "en";
    } else if (browserLang.indexOf("cs") == 0) {
        returnLang = "cs";
    } else if (browserLang.indexOf("de") == 0) {
        returnLang = "de";
    } else if (browserLang.indexOf("es") == 0) {
        returnLang = "es";
    } else if (browserLang.indexOf("fr") == 0) {
        returnLang = "fr";
    } else if (browserLang.indexOf("hu") == 0) {
        returnLang = "hu";
    } else if (browserLang.indexOf("it") == 0) {
        returnLang = "it";
    } else if (browserLang.indexOf("js") == 0) {
        returnLang = "js";
    } else if (browserLang.indexOf("pl") == 0) {
        returnLang = "pl";
    } else if (browserLang.indexOf("pt") == 0) {
        returnLang = "pt";
    } else if (browserLang.indexOf("ru") == 0) {
        returnLang = "ru";
    } else if (browserLang.indexOf("sk") == 0) {
        returnLang = "sk";
    } else if (browserLang.indexOf("zh-cn") == 0) {
        returnLang = "zh-cn";
    } else if (browserLang.indexOf("zh-tw") == 0) {
        returnLang = "zh-tw";
    }

    return returnLang;
}


/**
 * Replaces some values in text.
 * 
 * %*reqservername%  is replaced with the address of the host.
 * 
 * @param linkArray
 */
function replaceMacrosInArray(linkArray) {

    var hostName = window.location.hostname;

    // For now only changing the server name.
    // There may be others that we discover.
    if (linkArray != null) {
        for (var i = 0; i < linkArray.length; i++) {
            var elementString = linkArray[i];
            if ((typeof elementString) == "string") {
                elementString = elementString.replace("%*reqservername%", hostName);
                linkArray[i] = elementString;
            }
        }
    }

}


/**
 * Dynamically includes a JavaScript file.
 * 
 * Throws an exception if the file can not be found.
 * 
 * @param file
 *  the file to be included.
 * 
 */
function wpInclude(file) 
{
    if (document.createElement && document.getElementsByTagName) {
        var head = document.getElementsByTagName('head')[0];
        var script = document.createElement('script');
        script.setAttribute('type', 'text/javascript');
        script.setAttribute('src', file);
        head.appendChild(script);
    } else {
        alert('Your browser does\'t handle the DOM standard well.');
    }
}


/**
 * Dynamically includes a JavaScript file and runs it. This is
 * the interface that is used by the includes.ja file, which
 * includes all of the script files for the products.
 * 
 * @param scriptName
 *      name of the script to be included.
 */
function addWelcomePageScript(scriptName) {
    try {
        wpInclude(scriptName);
    } catch ( e ) {
        // If an error occurs, it will probably be because the script
        // does not exist. Just ignore it if the script doesn't exist.
        // This is an expected error.
        //
    }
}


//
// Functions to be used by those who write the web pages.
// 
// writeWpManagementLinks
// writeWpDownloadLinks
// writeWpWebAccessLinks
// 

function writeWpDownloadLinks(language) {

    var bSuccess = true;

    if ( linksExistForType(LINKTYPE_DOWNLOAD)) {

        //for (var key in wpProductNames) {
        var sortedKeys = getSortedWpProductKeys();
        for (var x = 0; x < sortedKeys.length; x++ ) {
            var key = sortedKeys[x];

            var productName = getWpI18NProductName(key, language);

            var links = getWpLinksByLinkType(key, language, LINKTYPE_DOWNLOAD);
            if (links != null) {

                document.write("<h4>" + productName + "</h4>\r\n");
                document.write('<ul class="links">\r\n');
                for ( var i = 0; i < links.length; i++) {
                    var descriptor = links[i][FIELD_DESCRIPTOR];
                    var url = links[i][FIELD_URL];
                    var target = links[i][FIELD_TARGET];
                    if (target != "") {
                        document.write("<li><a href='" + url + "' target='" + target + "'>" + descriptor + "</a></li>\r\n");
                    }
                    else {
                        document.write("<li><a href='" + url + "'>" + descriptor + "</a></li>\r\n");
                    }                 
                }
                document.write("</ul>\r\n");
            }
        }
        bSuccess = true;
    } else {
        bSuccess = false;
    }

    return bSuccess;
}



function writeWpManagementLinks(language) {
    
    var bSuccess = true;

    if ( linksExistForType(LINKTYPE_MANAGEMENT)) {

        document.write('<ul class="links">\r\n');

        //for (var key in wpProductNames) {
        var sortedKeys = getSortedWpProductKeys();
        for (var x = 0; x < sortedKeys.length; x++ ) {
            var key = sortedKeys[x];

            var productName = getWpI18NProductName(key, language);

            var links = getWpLinksByLinkType(key, language, LINKTYPE_MANAGEMENT);
            if (links != null) {

                for ( var i = 0; i < links.length; i++) {
                    var descriptor = links[i][FIELD_DESCRIPTOR];
                    var url = links[i][FIELD_URL];
                    var target = links[i][FIELD_TARGET];
                    if (target != "") {
                        document.write("<li><a href='" + url + "' target='" + target + "'>" + descriptor + "</a></li>\r\n");
                    }
                    else {
                        document.write("<li><a href='" + url + "' target='_blank'>" + descriptor + "</a></li>\r\n");
                    }
                }
            }
        }
        document.write("</ul>\r\n");
        bSuccess = true;
    } else {
        bSuccess = false;
    }

    return bSuccess;
}


function writeWpWebAccessLinks(language) {

    var bSuccess = true;

    if ( linksExistForType(LINKTYPE_WEBACCESS)) {

        document.write('<ul class="links">\r\n');

        //for (var key in wpProductNames) {
        var sortedKeys = getSortedWpProductKeys();
        for (var x = 0; x < sortedKeys.length; x++ ) {
            var key = sortedKeys[x];
            var productName = getWpI18NProductName(key, language);

            var links = getWpLinksByLinkType(key, language, LINKTYPE_WEBACCESS);
            if (links != null) {

                for ( var i = 0; i < links.length; i++) {
                    var descriptor = links[i][FIELD_DESCRIPTOR];
                    var url = links[i][FIELD_URL];
                    var target = links[i][FIELD_TARGET];
                    if (target != "") {
                        document.write("<li><a href='" + url + "' target='" + target + "'>" + descriptor + "</a></li>\r\n");
                    }
                    else {
                        document.write("<li><a href='" + url + "' target='_blank'>" + descriptor + "</a></li>\r\n");
                    }
                }
            }
        }
        document.write("</ul>\r\n");
        bSuccess = true;
    } else {
        bSuccess = false;    
    }

    return bSuccess;
}

//
// Content beyond this point is appended from the wpage_includes_nw.js or wpage_includes_linux.js file
// depending upon which version of the OS the build is going to.
// 


//
// Welcome page JavaScript files that are specific to OES2 -- Linux
//

document.write('<script type="text/javascript" src="/welcome/links/arkmanagerclient.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/ifolder3client.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/ifolder3server.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/imanager.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/imonitor.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/iprint.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/netstorage.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/remotemanager.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/javaconsole.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/storm.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/nfarm_win32.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/nfarm_win64.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/nfarm_macos.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/cis.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/cisclient.js">\r\n</script>\r\n');
document.write('<script type="text/javascript" src="/welcome/links/iPrintMobility.js">\r\n</script>\r\n');
